@@ -4,7 +4,7 @@ import sys
 from pathlib import Path
 
 
-def import_app(app: str):
+def import_app(app: str, handlers_dir: str):
     app_modal, app_name = app.split(":")
     app_path = f"{os.path.abspath(Path(app_modal))}.py"
 
@@ -13,6 +13,8 @@ def import_app(app: str):
     sys.modules[app_modal] = main
     spec.loader.exec_module(main)
 
+    load_handlers(handlers_dir)
+
     return getattr(main, app_name)
 
 
